==> haskell-shakespeare-2.0.13-13-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-shakespeare.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: shakespeare
version: 2.0.13
id: shakespeare-2.0.13-KCXl8uUSnCQKF0QGMG79cz
key: shakespeare-2.0.13-KCXl8uUSnCQKF0QGMG79cz
license: MIT
maintainer: Michael Snoyman <michael@snoyman.com>
stability: Stable
homepage: http://www.yesodweb.com/book/shakespearean-templates
synopsis: A toolkit for making compile-time interpolated templates
description:
    Shakespeare is a family of type-safe, efficient template languages. Shakespeare templates are expanded at compile-time, ensuring that all interpolated variables are in scope. Variables are interpolated according to their type through a typeclass.
    .
    Shakespeare templates can be used inline with a quasi-quoter or in an external file.
    .
    Note there is no dependency on haskell-src-extras. Instead Shakespeare believes logic should stay out of templates and has its own minimal Haskell parser.
    .
    Packages that use this: xml-hamlet
    .
    Please see the documentation at <http://www.yesodweb.com/book/shakespearean-templates> for more details.
category: Web, Yesod
author: Michael Snoyman <michael@snoyman.com>
exposed: True
exposed-modules:
    Text.Shakespeare.I18N Text.Shakespeare.Text Text.Roy Text.Julius
    Text.Coffee Text.Hamlet Text.Hamlet.RT Text.Hamlet.Runtime
    Text.Lucius Text.Cassius Text.Shakespeare.Base Text.Shakespeare
    Text.TypeScript Text.Internal.Css Text.Internal.CssCommon
hidden-modules: Text.Hamlet.Parse Text.MkSizeType
                Text.IndentToBrace
abi: 8906d4745eb2e5a57a16599dcbaa9b90
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/shakespeare-2.0.13
library-dirs: /usr/lib/ghc-8.0.2/site-local/shakespeare-2.0.13
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.0.2/shakespeare-2.0.13
hs-libraries: HSshakespeare-2.0.13-KCXl8uUSnCQKF0QGMG79cz
depends:
    aeson-1.1.2.0-8R262j8BseM7FTnCfGfbwu base-4.9.1.0
    blaze-html-0.8.1.3-EHw0sCLFL6JKZx2lFkE5O8
    blaze-markup-0.7.1.1-Amik95gvtJH76XeEGEdOV0 bytestring-0.10.8.1
    containers-0.5.7.1 directory-1.3.0.0
    exceptions-0.8.3-8AMTYj188ri8VOH6LXt0Fd ghc-prim-0.5.0.0
    parsec-3.1.11-1CA7c0vSU7tJHGhveOjoXR process-1.4.3.0
    scientific-0.3.5.1-3aJEdQvcyho88FhIoGrzGS template-haskell-2.11.1.0
    text-1.2.2.2-3ENqlljngKa6xj1Go2fVWq time-1.6.0.1
    transformers-0.5.2.0
    unordered-containers-0.2.8.0-1tqMF698WJE3INvmpuzQZc
    vector-0.12.0.1-692PQMDMB6pIQ1uGwefDcQ
haddock-interfaces: /usr/share/doc/haskell-shakespeare/html/shakespeare.haddock
haddock-html: /usr/share/doc/haskell-shakespeare/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-shakespeare-2.0.13-15-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-shakespeare.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: shakespeare
version: 2.0.13
id: shakespeare-2.0.13-38oTY9uXq2L6Yqytfi5GZl
key: shakespeare-2.0.13-38oTY9uXq2L6Yqytfi5GZl
license: MIT
maintainer: Michael Snoyman <michael@snoyman.com>
stability: Stable
homepage: http://www.yesodweb.com/book/shakespearean-templates
synopsis: A toolkit for making compile-time interpolated templates
description:
    Shakespeare is a family of type-safe, efficient template languages. Shakespeare templates are expanded at compile-time, ensuring that all interpolated variables are in scope. Variables are interpolated according to their type through a typeclass.
    .
    Shakespeare templates can be used inline with a quasi-quoter or in an external file.
    .
    Note there is no dependency on haskell-src-extras. Instead Shakespeare believes logic should stay out of templates and has its own minimal Haskell parser.
    .
    Packages that use this: xml-hamlet
    .
    Please see the documentation at <http://www.yesodweb.com/book/shakespearean-templates> for more details.
category: Web, Yesod
author: Michael Snoyman <michael@snoyman.com>
exposed: True
exposed-modules:
    Text.Shakespeare.I18N Text.Shakespeare.Text Text.Roy Text.Julius
    Text.Coffee Text.Hamlet Text.Hamlet.RT Text.Hamlet.Runtime
    Text.Lucius Text.Cassius Text.Shakespeare.Base Text.Shakespeare
    Text.TypeScript Text.Internal.Css Text.Internal.CssCommon
hidden-modules: Text.Hamlet.Parse Text.MkSizeType
                Text.IndentToBrace
abi: 93ded517d3bd9d050f1b80722dcb1ff8
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/shakespeare-2.0.13
library-dirs: /usr/lib/ghc-8.0.2/site-local/shakespeare-2.0.13
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.0.2/shakespeare-2.0.13
hs-libraries: HSshakespeare-2.0.13-38oTY9uXq2L6Yqytfi5GZl
depends:
    aeson-1.2.1.0-LtwtJj4trOg6E4DiroefXf base-4.9.1.0
    blaze-html-0.9.0.1-6LoDCyuiOhm81hDccML19n
    blaze-markup-0.8.0.0-6wPbGvG5gVcIJK8r30JWLy bytestring-0.10.8.1
    containers-0.5.7.1 directory-1.3.0.0
    exceptions-0.8.3-8AMTYj188ri8VOH6LXt0Fd ghc-prim-0.5.0.0
    parsec-3.1.11-1CA7c0vSU7tJHGhveOjoXR process-1.4.3.0
    scientific-0.3.5.1-3aJEdQvcyho88FhIoGrzGS template-haskell-2.11.1.0
    text-1.2.2.2-3ENqlljngKa6xj1Go2fVWq time-1.6.0.1
    transformers-0.5.2.0
    unordered-containers-0.2.8.0-1tqMF698WJE3INvmpuzQZc
    vector-0.12.0.1-692PQMDMB6pIQ1uGwefDcQ
haddock-interfaces: /usr/share/doc/haskell-shakespeare/html/shakespeare.haddock
haddock-html: /usr/share/doc/haskell-shakespeare/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
